# BEE Workflows

This is a home for workflows which demonstrate BEE functionality.


Directories:
* `clamr-wf`: CLAMR workflow with yaml files. The workflow executes CLAMR in a container, then processes png files getnerated by CLAMR into an MPEG video using ffmpeg on bare metal. This is a good example to test running both in a container and on bare metal.

* `clamr-wf-noyaml/`: Original workflows with all parameters on the command line. The workflows execute CLAMR in a container, and then processes png files generated by CLAMR into an MPEG video, using ffmpeg. There are examples for container runtimes, Charliecloud and Singularity, and for workload schedulers, LSF and Slurm. The selection of container runtime and workload scheduler are defined in the bee.conf configuration file.

* `clamr-wf-singularity`: CLAMR workflow with yaml files. The workflow executes CLAMR in a Singularity container, then processes png files getnerated by CLAMR into an MPEG video using ffmpeg on bare metal. 

* `clamr-wf-summit`: CLAMR workflow with yaml files that runs on Summit, using LSF. This workflow executes both the clamr and ffmpeg steps in a container.

* `simple-workflow/`: Contains some example workflows used for tests and simple demonstrations of running workflows with BEE.
